#[non_exhaustive]pub enum AddressBackendError {
InputContainsRawNewlines,
#[non_exhaustive] InputTooLong {
len: usize,
max: usize,
},
HeaderParse,
MissingAddress,
MissingAddrSpec,
InvalidAddrSpec {
input: String,
source: EmailAddressParseError,
},
GroupMemberMissingAddrSpec {
index: usize,
},
InvalidGroupMemberAddrSpec {
index: usize,
input: String,
source: EmailAddressParseError,
},
GroupMissingName,
}Expand description
Low-level failures reported by the address parsing backend.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InputContainsRawNewlines
The input contains a raw carriage return or line feed.
#[non_exhaustive]InputTooLong
The input exceeds MAX_ADDRESS_INPUT_BYTES.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.
HeaderParse
The backend could not parse the synthetic address header.
MissingAddress
The parsed header did not contain address data.
MissingAddrSpec
A mailbox did not contain an addr-spec.
InvalidAddrSpec
A mailbox contained an invalid addr-spec.
Fields

source: EmailAddressParseErrorUnderlying email-address validation error.
GroupMemberMissingAddrSpec
A group member did not contain an addr-spec.
InvalidGroupMemberAddrSpec
A group member contained an invalid addr-spec.
Fields

source: EmailAddressParseErrorUnderlying email-address validation error.
GroupMissingName
A parsed group did not contain a name.